==> home-made-io-fastmag-sync-m2-0.22.2-b65669.zip: Process/Worker/Integration.php <==
<?php
/*******************************************************************************
 * Created by HOMEMADE.IO SAS.
 * Fastmag Sync  -  Connect Fastmag with your Magento
 *
 * Copyright (C) HOMEMADE.IO SAS, Inc - All Rights Reserved
 *
 * @author    Simon Laubet-Xavier <simon.laubetxavier@home-made.io>
 * @copyright 2020-2021 HOMEMADE.IO SAS
 * @date      2021-08-26
 ******************************************************************************/

namespace Fastmag\Sync\Process\Worker;

use Fastmag\Sync\Exception\JobException;
use Fastmag\Sync\Exception\ProcessException;
use Fastmag\Sync\Model\Jobqueue;

/**
 * Trait Integration
 *
 * Trait for all integration workers (to Fastmag and to Magento)
 */
trait Integration
{
    use Standard;

    /**
     * @inheritDoc
     */
    public function run()
    {
        try {
            $this->initiate();
        } catch (ProcessException $exception) {
            $this->logger->notice($exception->getMessage());

            return;
        }

        foreach ($this->getJobs()->getItems() as $job) {
            if (!$job->isInError()) {
                try {
                    $this->processJob($job);
                } catch (JobException $exception) {
                    $this->invalidateJob($job, $exception);
                }

                $this->saveJob($job);
            }
        }
    }

    /**
     * Returns the activation of the synchronization of the current entity
     *
     * @return bool
     */
    abstract public function isEnabled();

    /**
     * Process job
     *
     * @param Jobqueue $job
     *
     * @return void
     *
     * @throws JobException
     */
    abstract protected function processJob($job);

    /**
     * Check initial conditions to run the worker
     *
     * @throws ProcessException
     */
    protected function initiate()
    {
        if (!$this->isEnabled()) {
            throw new ProcessException(__('Worker "%1" was called, even though it is disabled', $this->code));
        } elseif ($this->getJobs()->count() <= 0) {
            throw new ProcessException(__('Worker "%1" was called, but without jobs to integrate', $this->code));
        }
    }
}

==> home-made-io-fastmag-sync-m2-1.0.0-546904.zip: Process/Worker/Integration.php <==
<?php
/*******************************************************************************
 * Created by HOMEMADE.IO SAS.
 * Fastmag Sync  -  Connect Fastmag with your Magento
 *
 * Copyright (C) HOMEMADE.IO SAS, Inc - All Rights Reserved
 *
 * @author    Simon Laubet-Xavier <simon.laubetxavier@home-made.io>
 * @copyright 2020-2021 HOMEMADE.IO SAS
 * @date      2021-09-27
 ******************************************************************************/

namespace Fastmag\Sync\Process\Worker;

use Fastmag\Sync\Exception\JobException;
use Fastmag\Sync\Exception\ProcessException;
use Fastmag\Sync\Model\Jobqueue;

/**
 * Trait Integration
 *
 * Trait for all integration workers (to Fastmag and to Magento)
 */
trait Integration
{
    use Standard;

    /**
     * @inheritDoc
     */
    public function run()
    {
        try {
            $this->initiate();
        } catch (ProcessException $exception) {
            $this->logger->notice($exception->getMessage());

            return;
        }

        foreach ($this->getJobs()->getItems() as $job) {
            if (!$job->isInError()) {
                try {
                    $this->processJob($job);
                } catch (JobException $exception) {
                    $this->invalidateJob($job, $exception);
                }

                $this->saveJob($job);
            }
        }
    }

    /**
     * Returns the activation of the synchronization of the current entity
     *
     * @return bool
     */
    abstract public function isEnabled();

    /**
     * Process job
     *
     * @param Jobqueue $job
     *
     * @return void
     *
     * @throws JobException
     */
    abstract protected function processJob($job);

    /**
     * Check initial conditions to run the worker
     *
     * @throws ProcessException
     */
    protected function initiate()
    {
        if (!$this->isEnabled()) {
            throw new ProcessException(__('Worker "%1" was called, even though it is disabled', $this->code));
        } elseif ($this->getJobs()->count() <= 0) {
            throw new ProcessException(__('Worker "%1" was called, but without jobs to integrate', $this->code));
        }
    }

    /**
     * Returns the hydration worker code
     *
     * @return string|null
     */
    public function getHydrationWorker()
    {
        return (property_exists($this, 'hydrationWorker') ? $this->hydrationWorker : null);
    }
}
